@@ -206,10 +206,9 @@ class EscriptoriumConnector:
         transcription_content: str,
         graphs: Union[Any, None],
     ):
-        # Do I need a "transcription" field too? I don't know what it means.
         payload = {
-            "pk": transcription_pk,
             "line": line_pk,
+            "transcription": transcription_pk,
             "content": transcription_content,
         }
         if graphs is not None:
@@ -339,10 +338,11 @@ class EscriptoriumConnector:
     def upload_part_transcription(
         self,
         document_pk: int,
-        part_pk: int,
+        part_pk: Union[list[int], int],
         transcription_name: str,
         filename: str,
         file_data: BufferedReader,
+        override: str = "off",
     ):
         """Upload a txt, PageXML, or ALTO file.
 
@@ -352,6 +352,7 @@ class EscriptoriumConnector:
             transcription_name (str): Transcription name
             filename (str): Filename
             file_data (BufferedReader): File data as a BufferedReader
+            override (str): Whether to override existing segmentation data ("on") or not ("off", default)
 
         Returns:
             null: Nothing
@@ -364,6 +365,7 @@ class EscriptoriumConnector:
                 "name": transcription_name,
                 "document": document_pk,
                 "parts": part_pk,
+                "override": override,
             },
             {"upload_file": (filename, file_data)},
         )
